@@ -1,3 +1,5 @@
+import asyncio
+
 from vkwave.client import AIOHTTPClient
 from vkwave.api import API as LibAPI
 from vkwave.api.token import Token
@@ -17,7 +19,18 @@ class API:
     async def close(self) -> None:
         await self._api.default_api_options.clients[0].close()
 
+
+class SyncAPI:
+    def __init__(self, token: str):
+        self._api = API(token)
+
+    def api_request(self, _method: str, **kwargs):
+        loop = asyncio.get_event_loop()
+        if loop.is_running():
+            raise RuntimeError("'SyncAPI' can't be used with already running asyncio event loop")
+        return loop.run_until_complete(self._api.get_api().api_request(_method, kwargs))
+
+
 def run(f):
-    import asyncio
     loop = asyncio.get_event_loop()
     loop.run_until_complete(f)
